@@ -5,6 +5,7 @@
 #
 # \description{
 #  @get "title".
+#  By default, this function will set it to \code{~/.Rcache/}.
 # }
 #
 # @synopsis
@@ -32,18 +33,31 @@ setMethodS3("setCacheRootPath", "default", function(path="~/.Rcache", ...) {
 
   if (!isDirectory(path)) {
     mkdirs(path);
-    if (!isDirectory(path))
+    if (!isDirectory(path)) {
       throw("Could not create cache directory: ", path);
+    }
+  }
+
+  # Add a README.txt to cache root (expaining what the directory is)
+  filename <- "README.txt";
+  pathnameD <- file.path(path, filename);
+  if (!isFile(pathnameD)) {
+    pathnameS <- system.file(".Rcache", filename, package="R.cache");
+    file.copy(pathnameS, pathnameD);
   }
 
   ovalue <- options("R.cache::rootPath"=path);
 
   invisible(ovalue);
-})
+}) # setCacheRootPath()
 
 
 ############################################################################
 # HISTORY:
+# 2011-12-29
+# o Now setCacheRootPath() adds a README.txt file to the root path, iff
+#   missing. It explains why the directory structure exists and what
+#   created it.
 # 2007-03-07
 # o Changed the default root path to ~/.Rcache/
 # 2007-01-24
